FzfScheme

Enum FzfScheme 

pub enum FzfScheme {
    Default,
    Path,
    History,
}
Available on crate features fzf-v1 or fzf-v2 only.
A type used to tweak the distance algorithm.

This enum can be passed to both FzfV1 and FzfV2 to tweak the distance algorithm based on the type of candidates being searched.

Variants



Default

A generic distance scheme that works well for any type of input.



Path

A distance scheme tailored for searching file paths. It assigns additional bonus points to the character immediately following a path separator (i.e. / on Unix-like systems and \ on Windows).



History

A distance scheme tailored for searching shell command history which doesn’t assign any additional bonus points.